import { Type } from './types/types';
import { Diagnostic } from 'vscode-languageserver';
import { SuffixTypeBuilder } from './suffixTypeNode';
/**
 * type result for a kerboscript expression
 */
export interface ITypeResultExpr<T extends Type> {
    /**
     * result type
     */
    type: T;
    /**
     * errors encountered during this expression type check
     */
    errors: Diagnostic[];
}
/**
 * type result for a kerboscript suffix
 */
export interface ITypeResultSuffix<T extends SuffixTypeBuilder = SuffixTypeBuilder> {
    /**
     * resolved cummulative suffix types
     */
    builder: T;
    /**
     * errors encounted during this suffix type check
     */
    errors: Diagnostic[];
}
/**
 * What is the kind of this type
 */
export declare const enum TypeKind {
    basic = 0,
    variadic = 1,
    suffix = 2,
    function = 3
}
/**
 * What is the kind of this call
 */
export declare const enum CallKind {
    get = 0,
    set = 1,
    call = 2,
    optionalCall = 3
}
/**
 * What operator kind is present
 */
export declare const enum OperatorKind {
    plus = 0,
    subtract = 1,
    multiply = 2,
    divide = 3,
    power = 4,
    greaterThan = 5,
    lessThan = 6,
    greaterThanEqual = 7,
    lessThanEqual = 8,
    notEqual = 9,
    equal = 10,
    boolean = 11
}
