import { RunStmtType } from '../parser/types';
import { ILoadData } from '../types';
import { Location, Diagnostic } from 'vscode-languageserver';
import { URI } from 'vscode-uri';
/**
 * Class to resolve run statements or calls to file paths
 */
export declare class PathResolver {
    /**
     * The path corresponding to root of volume 0 of the kos directory
     */
    volume0Uri?: URI;
    /**
     * Create an instance of that path resolve.
     * @param volume0Uri the uri associated with volume 0
     */
    constructor(volume0Uri?: string);
    /**
     * Is the resolve ready to resolve paths
     */
    readonly ready: boolean;
    /**
     * Resolve uri to load data
     * @param caller location of caller
     * @param runPath path provided in a run statement
     */
    resolveUri(caller: Location, runPath?: string): Maybe<ILoadData>;
    /**
     * Creates a load data payload from a caller and path segments
     * @param caller call location
     * @param pathSegments path segments
     */
    private loadData;
}
/**
 * based on run type determine how to get file path
 * @param stmt run statement
 */
export declare const runPath: (stmt: RunStmtType) => string | Diagnostic;
